@@ -81,12 +81,10 @@ use parent qw( Crypt::Perl::ECDSA::KeyBase );
 use Try::Tiny;
 
 use Bytes::Random::Secure::Tiny ();
-use Module::Load ();
 
 use Crypt::Perl::ASN1 ();
 use Crypt::Perl::BigInt ();
 use Crypt::Perl::PKCS8 ();
-use Crypt::Perl::RNG ();
 use Crypt::Perl::Math ();
 use Crypt::Perl::ToDER ();
 use Crypt::Perl::X ();
@@ -106,6 +104,8 @@ use constant ASN1_PRIVATE => Crypt::Perl::ECDSA::KeyBase->ASN1_Params() . q<
 
 use constant _PEM_HEADER => 'EC PRIVATE KEY';
 
+use constant NUMBER_CLASS => 'Crypt::Perl::BigInt';
+
 #$curve_parts is also a hash ref, defined as whatever the ASN.1
 #parse of the main key’s “parameters” returned, whether that be
 #explicit key parameters or a named curve.
@@ -114,24 +114,26 @@ sub new {
     my ($class, $key_parts, $curve_parts) = @_;
 
     if (!length $key_parts->{'version'}) {
-        die 'Need a “version”! (Try 1)';
+        die Crypt::Perl::X::create('Generic', 'Need a “version”! (Try 1)');
     }
 
     my $self = {
         version => $key_parts->{'version'},
     };
 
-    for my $k ( qw( private public ) ) {
-        if ( try { $key_parts->{$k}->isa('Crypt::Perl::BigInt') } ) {
+    bless $self, $class;
+
+    $self->_set_public( $key_parts->{'public'} );
+
+    for my $k ( qw( private ) ) {
+        if ( try { $key_parts->{$k}->isa(NUMBER_CLASS()) } ) {
             $self->{$k} = $key_parts->{$k};
         }
         else {
-            die "“$k” must be “Crypt::Perl::BigInt”, not “$key_parts->{$k}”!";
+            die Crypt::Perl::X::create('Generic', sprintf "“$k” must be “%s”, not “$key_parts->{$k}”!", NUMBER_CLASS());
         }
     }
 
-    bless $self, $class;
-
     return $self->_add_params( $curve_parts );
 }
 
@@ -160,11 +162,15 @@ sub sign_jwa {
 sub get_public_key {
     my ($self) = @_;
 
-    Module::Load::load('Crypt::Perl::ECDSA::PublicKey');
+    require Crypt::Perl::ECDSA::PublicKey;
+
+    my $curve_hr = $self->_explicit_curve_parameters( seed => 1 );
+    my $ccurve_hr = $curve_hr->{'ecParameters'}{'curve'};
+    $ccurve_hr->{'seed'} = [ $ccurve_hr->{'seed'} ];
 
     return Crypt::Perl::ECDSA::PublicKey->new(
-        $self->{'public'},
-        $self->_explicit_curve_parameters(),
+        $self->_decompress_public_point(),
+        $curve_hr,
     );
 }
 
@@ -173,7 +179,7 @@ sub get_struct_for_private_jwk {
 
     my $hr = $self->get_struct_for_public_jwk();
 
-    Module::Load::load('MIME::Base64');
+    require MIME::Base64;
 
     $hr->{'d'} = MIME::Base64::encode_base64url( $self->{'private'}->as_bytes() );
 
@@ -217,7 +223,7 @@ sub _sign {
 #printf "Q.y: %s\n", $Q->{'y'}->to_bigint()->as_hex();
 #printf "Q.z: %s\n", $Q->{'z'}->as_hex();
         $r = $Q->get_x()->to_bigint()->copy()->bmod($n);
-    } while ($r <= 0);
+    } while !$r->is_positive();
 
 #printf "k: %s\n", $k->as_hex();
 #printf "n: %s\n", $n->as_hex();
@@ -236,7 +242,7 @@ sub _sign {
 }
 
 sub _get_asn1_parts {
-    my ($self, $curve_parts) = @_;
+    my ($self, $curve_parts, @params) = @_;
 
     my $private_str = $self->{'private'}->as_bytes();
 
@@ -248,6 +254,7 @@ sub _get_asn1_parts {
             privateKey => $private_str,
             parameters => $curve_parts,
         },
+        @params,
     );
 }
 
